@@ -5,7 +5,7 @@ use Carp;
 use Scalar::Util qw( refaddr reftype );
 use IO::Select;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # interal socket information table
 my %SOCK_INFO;
@@ -315,8 +315,9 @@ Net::Proxy - Framework for proxying network connections in many ways
     # proxy connections from localhost:6789 to remotehost:9876
     # using standard TCP connections
     my $proxy = Net::Proxy->new(
-        in  => { type => tcp, port => '6789' },
-        out => { type => tcp, host => 'remotehost', port => '9876' },
+        {   in  => { type => tcp, port => '6789' },
+            out => { type => tcp, host => 'remotehost', port => '9876' },
+        }
     );
 
     # register the proxy object
@@ -521,67 +522,12 @@ all proxy objects.
 
 =back
 
-=head1 AVAILABLE CONNECTORS
+=head1 CONNECTORS
 
 All connection types are provided with the help of specialised classes.
 The logic for protocol C<xxx> is provided by the C<Net::Proxy::Connector::xxx>
 class.
 
-=head2 tcp (C<Net::Proxy::Connector::tcp>)
-
-This is the simplest possible proxy. On the "in" side, it sits waiting
-for incoming connections, and on the "out" side, it connects to the
-configured host/port.
-
-=head2 connect (C<Net::Proxy::Connector::connect>)
-
-This proxy can connect to a TCP server though a web proxy that
-accepts HTTP CONNECT requests.
-
-=head2 dual (C<Net::Proxy::Connector::dual>)
-
-This proxy is a Y-shaped proxy: depending on the client behaviour
-right after the connection is established, it connects it to one
-of two services, handled by two distinct connectors.
-
-=head2 dummy (C<Net::Proxy::Connector::dummy>)
-
-This proxy does nothing. You can use it as a template for writing
-new C<Net::Proxy::Connector> classes.
-
-=head2 Summary
-
-This table summarises all the available C<Net::Proxy::Connector>
-classes and the parameters their constructors recognise.
-
-C<N/A> means that the given C<Net::Proxy::Connector> cannot be used
-in that position (either C<in> or C<out>).
-
-     Connector  | in parameters   | out parameters
-    ------------+-----------------+----------------
-     tcp        | host            | host
-                | port            | port
-    ------------+-----------------+----------------
-     connect    | N/A             | host
-                |                 | port
-                |                 | proxy_host
-                |                 | proxy_port
-                |                 | proxy_user
-                |                 | proxy_pass
-                |                 | proxy_agent
-    ------------+-----------------+----------------
-     dual       | host            | N/A
-                | port            |
-                | timeout         |
-                | server_first    |
-                | client_first    |
-    ------------+-----------------+----------------
-     dummy      | N/A             | N/A
-
-C<Net::Proxy::Connector::dummy> is used as the C<out> parameter for
-a C<Net::Proxy::Connector::dual>, since the later is linked to two
-different connector objects.
-
 =head2 Connector hooks
 
 There is a single parameter that all connectors accept: C<hook>.
@@ -600,6 +546,71 @@ C<$connector> is the C<Net::Proxy::Connector> object that created the
 socket. This allows someone to eventually store data in a stash stored
 in the connector, so as to share data between sockets.
 
+=head2 Available connectors
+
+=over 4
+
+=item * tcp (C<Net::Proxy::Connector::tcp>)
+
+This is the simplest possible proxy connector. On the "in" side, it sits waiting
+for incoming connections, and on the "out" side, it connects to the
+configured host/port.
+
+=item * connect (C<Net::Proxy::Connector::connect>)
+
+This proxy connector can connect to a TCP server though a web proxy that
+accepts HTTP CONNECT requests.
+
+=item * dual (C<Net::Proxy::Connector::dual>)
+
+This proxy connector is a Y-shaped connector: depending on the client behaviour
+right after the connection is established, it connects it to one
+of two services, handled by two distinct connectors.
+
+=item * dummy (C<Net::Proxy::Connector::dummy>)
+
+This proxy connector does nothing. You can use it as a template for writing
+new C<Net::Proxy::Connector> classes.
+
+=back
+
+=head2 Summary
+
+This table summarises all the available C<Net::Proxy::Connector>
+classes and the parameters their constructors recognise.
+
+C<N/A> means that the given C<Net::Proxy::Connector> cannot be used
+in that position (either C<in> or C<out>).
+
+     Connector  | in parameters   | out parameters
+    ------------+-----------------+-----------------
+     tcp        | host            | host
+                | port            | port
+    ------------+-----------------+-----------------
+     connect    | N/A             | host
+                |                 | port
+                |                 | proxy_host
+                |                 | proxy_port
+                |                 | proxy_user
+                |                 | proxy_pass
+                |                 | proxy_agent
+    ------------+-----------------+-----------------
+     dual       | host            | N/A
+                | port            |
+                | timeout         |
+                | server_first    |
+                | client_first    |
+    ------------+-----------------+-----------------
+     dummy      | N/A             | N/A
+    ------------+-----------------+-----------------
+     ssl        | host            | host
+                | port            | port
+                | start_cleartext | start_cleartext
+
+C<Net::Proxy::Connector::dummy> is used as the C<out> parameter for
+a C<Net::Proxy::Connector::dual>, since the later is linked to two
+different connector objects.
+
 =head1 AUTHOR
 
 Philippe 'BooK' Bruhat, C<< <book@cpan.org> >>.
@@ -646,6 +657,19 @@ L<http://thomer.com/howtos/nstx.html> for examples.
 
 =item *
 
+Implement an UDP connector. (Is it feasible?)
+
+=item *
+
+Implement a connector that can be plugged to the STDIN/STDOUT of an
+external process, like the C<ProxyCommand> option of OpenSSH.
+
+=item *
+
+Implement C<Net::Proxy::Connector::unix>, for UNIX sockets.
+
+=item *
+
 Implement ICMP tunnel connectors.
 
 See
@@ -666,11 +690,15 @@ Look also here: L<http://gray-world.net/tools/>
 
 =item *
 
-Add support for SSL/TLS connectors.
+Implement a C<Net::Proxy::Connector::starttls> connector that can upgrade
+upgrade a connection to SSL transparently, even if the client or server
+doesn't support STARTTLS.
 
-Martin Werthmller provided a full implementation of a connector than
+Martin Werthmller provided a full implementation of a connector that
 can handle IMAP connections and upgrade them to TLS if the client sends
-a C<STARTTLS> command.
+a C<STARTTLS> command. My implementation will split this in two parts
+C<Net::Proxy::Connector::ssl> and C<Net::Proxy::Connector::starttls>,
+that inherits from the former.
 
 =back
 
